@@ -1,12 +1,8 @@
 """Module with some helpers for type hints and annotations."""
 
 from mypythontools.types.type_conversions_internal import json_to_py, str_to_bool, str_to_infer_type
-from mypythontools.types.type_hints_internal import (
-    get_return_type_hints,
-    small_validate,
-    typechecked_compatible,
-)
-from mypythontools.types.types_internal import validate_sequence
+from mypythontools.types.type_hints_internal import get_return_type_hints
+from mypythontools.types.validation import validate_sequence, small_validate, typechecked_compatible
 
 __all__ = [
     "get_return_type_hints",
